\name{simsel-package}
\alias{simsel-package}
\alias{simsel}
\docType{package}
\title{
Variable selection by SimSel
}
\description{
The package implements the linear and quadratic SimSel algorithms for variable selection. The Please see 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis) for details.
}
\details{
\tabular{ll}{
Package: \tab simsel\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2008-01-14\cr
License: \tab GPL\cr
}
~~ An overview of how to use the package, including the most important ~~
~~ functions ~~
}
\author{
Martin Eklund <martin.eklund@farmbio.uu.se>
Silvelyn Zwanzig <20@math.uu.se>
Maintainer: Martin Eklund <martin.eklund@farmbio.uu.se>
}
\references{
'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)
}
\keyword{ package }
\examples{
	########################################################
	# Linear, uncorrelated data with no measurement errors #
	########################################################
	# Construct uncorrelated independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a linear way on the dependent variables
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Run SimSel 1 times and plot graph the results.
	simsel.linear(X, Y)
	
	###########################################################
	# Nonlinear, uncorrelated data with no measurement errors #
	###########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 1 times and graph the results
	simsel.linear(X, Y)
	
	########################################################
	# Linear, uncorrelated data with no measurement errors #
	########################################################
	# Construct uncorrelated independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a linear way on the dependent variables
	Y <- X\%*\%c(1, 0, 1, 0, 0)
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.05)
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)
	
	###########################################################
	# Nonlinear, uncorrelated data with no measurement errors #
	###########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10 percent error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)	
}
