\name{simsel.quadratic.f}
\alias{simsel.quadratic.f}
\title{The quadratic SimSel algorithm run a number of times. F-statistics are plotted as violinplots.}
\description{
  Variable selection by quadratic SimSel
}
\usage{
simsel.quadratic.f(X, Y, max = 0.1, step = 0.001, rep = 100)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{Independent variables. NAs not allowed (yet).}
  \item{Y}{Dependent variable}
  \item{max}{The maximum value of the lambdas}
  \item{step}{The step size of the lambdas}
  \item{rep}{The number of times the procedure should be run}
}
\details{
Please see 'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)
}
\value{
Only graphics (violinplots).
}
\references{'SimSel - a new simulation method for variable selection' (submitted to Computational Statistics and Data Analysis)}
%\note{
%	The examples use special functions for generating the data: \code{\link{simulateLinearDataWithoutEIV}}, \link{simulateLinearDataWithEIV}}, \link{simulateNonLinearDataWithoutEIV}}, \link{simulateNonLinearDataWithEIV}}. These functions come with this package,
%}
\seealso{\code{\link{simsel.linear.f}}}
\examples{
	###########################################################
	# Nonlinear, uncorrelated data with no measurement errors #
	###########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error added to the dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)

	########################################################	
	# Nonlinear, uncorrelated data with measurement errors #
	########################################################
	# Construct independent variables	
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), diag(5))
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error to dependent variable	
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Add roughly 10% error added to the dependent variable
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)

	#########################################################	
	# Nonlinear, correlated data with no measurement errors #
	#########################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a nonlinear way on the dependent variables	
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% error to dependent variable	
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)

	######################################################	
	# Nonlinear, correlated data with measurement errors #
	######################################################
	# Construct moderately correlated independent variables
	randomSigma <- diag(5)
	for(i in 2:nrow(randomSigma))	{
		for(j in 1:i-1)	{
			tmp <- runif(1, -0.5, 0.5)
			randomSigma[i, j] <- tmp
			randomSigma[j, i] <- tmp
		}
	}
	randomSigma <- posdefify(randomSigma)
	X <- mvrnorm(100, c(0, 0, 0, 0, 0), randomSigma)
	# Construct dependent variable that depends in a nonlinear way on the dependent variables
	Y <- matrix(rep(0, nrow(X)), ncol=1)
	beta <- c(1, 0, 1, 0, 0)
	for(i in 1:length(beta))	{
		Y <- Y + (beta[i]*X[,i])^2 + 10*sin(beta[i]*X[,i])
	}
	# Add roughly 10% errors to dependent variable
	Y <- Y + rnorm(nrow(Y), 0, 0.5)
	# Add roughly 10% errors to independent variables
	for(i in 1:ncol(X))	{
		X[,i] <- X[,i] + rnorm(nrow(X), 0, 0.05)
	}
	# Run SimSel 100 times and plot F-statistic. Takes a little bit of time to run - please be patient
	simsel.linear.f(X, Y)

## The function is currently defined as
function(X, Y, max=0.1, step=0.001, rep=100)	{
	f <- NULL
	r2 <- NULL
	counter <- 1
	for(j in 1:rep)	{
		for(i in 1:ncol(X))	{
			tmp <- single.simsel.quadratic(X, Y, max, step, i)
			tmp <- as.matrix(tmp)
			tmp <- summary(lm(tmp[,1] ~ tmp[,2]))
			f[counter] <- tmp[[10]][1]	# F-stat
			r2[counter] <- tmp[[9]][1]	# Adjusted R-squared
#			f[counter] <- summary(lm(tmp[,1] ~ tmp[,2]))[[4]][8]	# p-value
			counter <- counter + 1
		}
	}
	fac <- factor(rep(1:ncol(X), rep))
	for(i in 1:ncol(X))	{
		r2i <- r2[fac==i]
		fi <- f[fac==i]		
		cat("Variable", i, " R-squared,  mean =", mean(r2i), ", stdv =", sqrt(var(r2i)), "\n")
		cat("            F-statistic, mean =", mean(fi), ", stdv =", sqrt(var(fi)), "\n")	
	}
	violinplot(f ~ fac, col = "brown")
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{NA}
